IndexedUndirectedGraph

Struct IndexedUndirectedGraph 

pub struct IndexedUndirectedGraph<C> { /* private fields */ }
An undirected graph stored as dense usize indices with weighted adjacency lists.

Implementations

Source

impl<C> IndexedUndirectedGraph<C>

pub fn from_edges(node_count: usize, edges: Vec<(usize, usize, C)>) -> Self
where C: Clone,

Build an undirected indexed graph from a list of edges.

pub const fn node_count(&self) -> usize

Return the number of nodes in the graph.

pub fn successors(&self, node: usize) -> &[(usize, C)]

Return the adjacency list for node.

pub fn edges(&self) -> &[(usize, usize, C)]

Return the canonical edge list (each edge appears once).

pub fn adjacency(&self) -> &[Vec<(usize, C)>]

Return all adjacency lists.

pub fn connected_components(&self) -> Vec<Vec<usize>>

Compute connected components of the graph.

pub fn component_index(&self) -> Vec<usize>

Return the component index for each node.

pub fn components(&self) -> Vec<Vec<usize>>

Return connected components (alias of Self::connected_components).

pub fn separate_components(&self) -> (Vec<usize>, Vec<usize>)

Separate connected components using neighbor groups derived from adjacency.

pub fn maximal_cliques_collect(&self) -> Vec<Vec<usize>>

Enumerate all maximal cliques and collect them into a vector.

pub fn maximal_cliques<CO>(&self, consumer: CO)
where CO: FnMut(&Vec<usize>),

Enumerate all maximal cliques and send them to consumer.

pub fn kruskal(&self) -> Vec<(usize, usize, C)>
where C: Clone + Ord,

Compute a minimum spanning tree using Kruskal’s algorithm (collected).

pub fn kruskal_indices(&self) -> impl Iterator<Item = (usize, usize, C)>
where C: Clone + Ord,

Compute a minimum spanning tree using Kruskal’s algorithm (iterator).

pub fn prim(&self) -> Vec<(usize, usize, C)>
where C: Clone + Ord,

Compute a minimum spanning tree using Prim’s algorithm.