pub struct IndexedGraphMap<N, C> { /* private fields */ }Expand description
Helper that maps external node values to dense indices and builds an indexed graph.
Implementations
Sourceimpl<N, C> IndexedGraphMap<N, C>
impl<N, C> IndexedGraphMap<N, C>
Sourcepub fn from_nodes_and_successors<I, FN, IN>(nodes: I, successors: FN) -> Self
pub fn from_nodes_and_successors<I, FN, IN>(nodes: I, successors: FN) -> Self
Build a mapped graph from seed nodes and a successor function.
Sourcepub const fn graph(&self) -> &IndexedGraph<C>
pub const fn graph(&self) -> &IndexedGraph<C>
Return the indexed graph.
Sourcepub fn into_graph(self) -> IndexedGraph<C>
pub fn into_graph(self) -> IndexedGraph<C>
Return the indexed graph, consuming the mapping helper.
Sourcepub const fn node_count(&self) -> usize
pub const fn node_count(&self) -> usize
Return the number of nodes in the mapped graph.